@@ -1,9 +1,9 @@
-# Copyright 2022 UW-IT, University of Washington
+# Copyright 2023 UW-IT, University of Washington
 # SPDX-License-Identifier: Apache-2.0
 
 
 from django.conf import settings
-from django.conf.urls import re_path
+from django.urls import re_path
 from uw_saml.views import LoginView, LogoutView, SSOView, MockSSOLoginView
 
 
